Module create

Module create 

Create a batch job via POST /batches.

![warn] This module is untested! If you encounter any issues, please report them on the repository.

Structs

CreateBatchRequest
Creates and executes a batch from an uploaded JSONL file of requests.

Enums

CompletionWindow
The time window within which a batch must complete.