Chat Completions API Module
This module provides components shared by many submodules.
Modules
- create
- Create a chat completion request.
- delete
- Module for deleting a stored chat completion.
- retrieve
- Module for retrieving chat completions from OpenAI API.
- update
- Module for updating stored chat completions.
Structs
- Annotation
- An annotation for a chat completion message.
- Chat
Completion - Chat
Completion Audio - If the audio output modality is requested, this object contains data about the audio response from the model. Learn more from OpenAI.
- Chat
Completion Message - Chat
Moderation - Moderation results for the request input and generated output.
- Choice
- Choice
Logprobs - Completion
Tokens Details - Completion
Usage - Message
Tool Call Custom - Message
Tool Call Function - Moderation
Side Result - A moderation result produced for the response input or generated output.
- Prompt
Tokens Details - Token
LogProb - TopLogprob
- UrlCitation
- A URL citation when the model uses a web search tool.
Enums
- Annotation
Type - The type of an annotation.
- Chat
Completion Message Tool Call - Chat
Completion Object - The object type, which is always
chat.completion. - Finish
Reason - The reason the model stopped generating tokens.
- Moderation
Result Type - The object type of a moderation result. Always
moderation_result. - Moderation
Side - The moderation outcome for one side (input or output) of the completion: either successful results or an error produced while attempting moderation.
- Role
- The role of the author of a message, as reported in responses and streamed deltas.
- Service
Tier - The service tier used for processing the request.
Type Aliases
- Response
Role - Legacy alias of
Role.