pub enum ToolChoiceSpecific {
AllowedTools {
allowed_tools: ToolChoiceAllowedTools,
},
Function {
function: ToolChoiceFunction,
},
Custom {
custom: ToolChoiceCustom,
},
}Variants
AllowedTools
Allowed tool configuration type. Always allowed_tools.
Fields

allowed_tools: ToolChoiceAllowedToolsConstrains the tools available to the model to a pre-defined set.
Function
For function calling, the type is always function.
Fields

function: ToolChoiceFunctionCustom
For custom tool calling, the type is always custom.
Fields

custom: ToolChoiceCustomTrait Implementations
Sourceimpl Clone for ToolChoiceSpecific
impl Clone for ToolChoiceSpecific
Sourceimpl Debug for ToolChoiceSpecific
impl Debug for ToolChoiceSpecific
Sourceimpl<'de> Deserialize<'de> for ToolChoiceSpecific
impl<'de> Deserialize<'de> for ToolChoiceSpecific
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more