pub struct ContentPartFile {
pub file_data: Option<String>,
pub file_id: Option<String>,
pub filename: Option<String>,
}Expand description
A file input for a content part. At least one of file_data and
file_id should be provided.
Fields
file_data: Option<String>The base64 encoded file data, used when passing the file to the model as a string.
file_id: Option<String>The ID of an uploaded file to use as input.
filename: Option<String>The name of the file, used when passing the file to the model as a string.