pub struct DeveloperMessage {
pub content: MessageContent,
pub name: Option<String>,
}Expand description
A developer message payload.
Fields
content: MessageContentThe contents of the developer message: plain text, or an array of text content parts.
name: Option<String>An optional name for the participant.
Provides the model information to differentiate between participants of the same role.