pub struct ToolChoiceAllowedTools {
pub mode: ToolChoiceAllowedToolsMode,
pub tools: Vec<Map<String, Value>>,
}Fields
mode: ToolChoiceAllowedToolsModeConstrains the tools available to the model to a pre-defined set.
autoallows the model to pick from among the allowed tools and generate a message.requiredrequires the model to call one or more of the allowed tools.
tools: Vec<Map<String, Value>>A list of tool definitions that the model should be allowed to call.
For the Chat Completions API, the list of tool definitions might look like:
[
{ "type": "function", "function": { "name": "get_weather" } },
{ "type": "function", "function": { "name": "get_time" } }
]Trait Implementations
Sourceimpl Clone for ToolChoiceAllowedTools
impl Clone for ToolChoiceAllowedTools
Sourceimpl Debug for ToolChoiceAllowedTools
impl Debug for ToolChoiceAllowedTools
Sourceimpl<'de> Deserialize<'de> for ToolChoiceAllowedTools
impl<'de> Deserialize<'de> for ToolChoiceAllowedTools
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more