Module streaming

Module streaming 

Streaming chat completion response.

Re-exports

pub use crate::chat::FinishReason;
pub use crate::chat::Role as CompletionRole;
pub use crate::chat::CompletionTokensDetails;
pub use crate::chat::CompletionUsage;
pub use crate::chat::PromptTokensDetails;

Structs

ChatCompletionChunk
ChoiceDelta
ChoiceDeltaFunctionCall
ChoiceDeltaToolCall
ChoiceDeltaToolCallFunction
ChoiceLogprobs
Log probability information for a choice.
CompletionChunkChoice
LogprobeContent
A list of message content tokens with log probability information.
TopLogprob
List of the most likely tokens and their log probability, at this token position. In rare cases, there may be fewer than the number of requested top_logprobs returned.

Enums

ChatCompletionChunkObject
The object type, which is always chat.completion.chunk.
ChoiceDeltaToolCallType
The type of a streamed tool call.