Module for retrieving chat completions from OpenAI API.
![warn] This module is untested! If you encounter any issues, please report them on the Codeberg repository.
Module for retrieving chat completions from OpenAI API.
![warn] This module is untested! If you encounter any issues, please report them on the Codeberg repository.