pub struct ModerationSideResult {
pub categories: HashMap<String, bool>,
pub category_applied_input_types: HashMap<String, Vec<String>>,
pub category_scores: HashMap<String, f64>,
pub flagged: bool,
pub model: String,
pub type_: ModerationResultType,
}Expand description
A moderation result produced for the response input or generated output.
Fields
categories: HashMap<String, bool>A dictionary of moderation categories to booleans, true if the
input is flagged under this category.
category_applied_input_types: HashMap<String, Vec<String>>Which modalities of input are reflected by the score for each
category, e.g. ["text"] or ["text", "image"].
category_scores: HashMap<String, f64>A dictionary of moderation categories to scores.
flagged: boolA boolean indicating whether the content was flagged by any category.
model: StringThe moderation model that produced this result.
type_: ModerationResultTypeThe object type, which is always moderation_result.