pub struct UrlCitation {
pub start_index: usize,
pub end_index: usize,
pub title: String,
pub url: String,
}Expand description
A URL citation when the model uses a web search tool.
Fields
start_index: usizeThe index of the first character of the URL citation in the message.
end_index: usizeThe index of the last character of the URL citation in the message.
title: StringThe title of the web resource.
url: StringThe URL of the web resource.