Module files

Module files 

Manage the files of a container via /containers/{container_id}/files.

![warn] This module is untested! If you encounter any issues, please report them on the repository.

Submodules: create, retrieve, delete, list and content.

Modules

content
Retrieve the raw content of a container file via GET /containers/{container_id}/files/{file_id}/content.
create
Create a container file via POST /containers/{container_id}/files.
delete
Delete a container file via DELETE /containers/{container_id}/files/{file_id}.
list
List the files of a container via GET /containers/{container_id}/files.
retrieve
Retrieve a container file via GET /containers/{container_id}/files/{file_id}.

Structs

ContainerFile
A file attached to a container.