Update a conversation via POST /conversations/{conversation_id}.
![warn] This module is untested! If you encounter any issues, please report them on the repository.
Structs
- Update
Conversation Request - Updates a conversation.
Update a conversation via POST /conversations/{conversation_id}.
![warn] This module is untested! If you encounter any issues, please report them on the repository.