Get a vector representation of a given input that can be easily consumed by machine learning models and algorithms.
Tested against the Alibaba Cloud Model Studio (Qwen, text-embedding-v4)
OpenAI-compatible /embeddings endpoint. Note that, unlike OpenAI, Qwen
currently only supports encoding_format: "float".