pub struct Embedding {
pub embedding: EmbeddingVector,
pub index: usize,
pub object: String,
}Expand description
Represents an embedding vector returned by the embedding endpoint.
Fields
embedding: EmbeddingVectorThe embedding vector.
With encoding_format: "base64", the API returns the vector as a
base64 encoded string instead of a list of floats.
index: usizeThe index of the embedding in the list of embeddings.
object: StringThe object type, which is always embedding.