Create an eval via POST /evals.
![warn] This module is untested! If you encounter any issues, please report them on the repository.
Structs
- Create
Eval Request - Creates an eval.
Create an eval via POST /evals.
![warn] This module is untested! If you encounter any issues, please report them on the repository.