Update an eval via POST /evals/{eval_id}.
![warn] This module is untested! If you encounter any issues, please report them on the repository.
Structs
- Update
Eval Request - Updates an eval (currently only its name and metadata).
Update an eval via POST /evals/{eval_id}.
![warn] This module is untested! If you encounter any issues, please report them on the repository.