Module content

Module content 

Returns the contents of the specified file.

![warn] This module is untested! OpenAI-compatible providers (DeepSeek, Qwen) are not known to implement this endpoint, and no OpenAI API key was available for testing. If you encounter any issues, please report them on the repository.

Modules

request