pub struct ContentRequest<'a> {
pub file_id: &'a str,
pub extra_query: HashMap<&'a str, &'a str>,
}Expand description
Returns the contents of the specified file as raw bytes.
Fields
file_id: &'a strThe ID of the file to use for this request.
extra_query: HashMap<&'a str, &'a str>Add additional query parameters to the request.