Creates an edited or extended image given an original image and a prompt.
Endpoint: POST /images/edits (multipart/form-data request / JSON
response).
![warn] This module is untested! No OpenAI-compatible provider accessible to this project implements this endpoint, and no OpenAI API key was available for testing. If you encounter any issues, please report them on the repository.
Structs
- Image
Edit Request - Creates an edited or extended image given an original image and a prompt.
Enums
- Input
Fidelity - Control how much effort the model will exert to match the style and features of input images.
- Quality
- The quality of the image that will be generated for GPT image models.