pub struct ImageGenerateRequest {
pub prompt: String,
pub model: Option<String>,
pub background: Option<Background>,
pub moderation: Option<Moderation>,
pub n: Option<u32>,
pub output_compression: Option<u32>,
pub output_format: Option<OutputFormat>,
pub quality: Option<Quality>,
pub response_format: Option<ImageResponseFormat>,
pub size: Option<String>,
pub style: Option<Style>,
pub user: Option<String>,
}Expand description
Creates an image given a prompt.
Fields
prompt: StringA text description of the desired image(s).
The maximum length is 32000 characters for the GPT image models, 1000
characters for dall-e-2 and 4000 characters for dall-e-3.
model: Option<String>The model to use for image generation. One of dall-e-2,
dall-e-3, or a GPT image model (gpt-image-1, gpt-image-1-mini,
gpt-image-1.5, gpt-image-2, or gpt-image-2-2026-04-21).
Defaults to dall-e-2 unless a parameter specific to the GPT image
models is used.
background: Option<Background>Allows to set transparency for the background of the generated
image(s). Must be one of transparent, opaque, or auto (default
value).
moderation: Option<Moderation>Control the content-moderation level for images generated by the GPT
image models. Must be either low for less restrictive filtering or
auto (default value).
n: Option<u32>The number of images to generate. Must be between 1 and 10. For
dall-e-3, only n=1 is supported.
output_compression: Option<u32>The compression level (0-100%) for the generated images.
This parameter is only supported for the GPT image models with the
webp or jpeg output formats, and defaults to 100.
output_format: Option<OutputFormat>The format in which the generated images are returned.
This parameter is only supported for the GPT image models. Must be
one of png, jpeg, or webp.
quality: Option<Quality>The quality of the image that will be generated.
auto(default value) will automatically select the best quality for the given model.high,mediumandloware supported for the GPT image models.hdandstandardare supported fordall-e-3.standardis the only option fordall-e-2.
response_format: Option<ImageResponseFormat>The format in which generated images with dall-e-2 and dall-e-3
are returned. Must be one of url or b64_json. URLs are only valid
for 60 minutes after the image has been generated. This parameter
isn’t supported for the GPT image models, which always return
base64-encoded images.
size: Option<String>The size of the generated images.
For the GPT image models, the standard sizes 1024x1024,
1536x1024, and 1024x1536 are supported (gpt-image-2 also
accepts arbitrary WIDTHxHEIGHT strings); auto is supported for
models that allow automatic sizing. For dall-e-2, use one of
256x256, 512x512, or 1024x1024. For dall-e-3, use one of
1024x1024, 1792x1024, or 1024x1792.
style: Option<Style>The style of the generated images.
This parameter is only supported for dall-e-3. Must be one of
vivid or natural.
user: Option<String>A unique identifier representing your end-user, which can help OpenAI to monitor and detect abuse.