Module variation

Module variation 

Creates a variation of a given image.

Endpoint: POST /images/variations (multipart/form-data request / JSON response). This endpoint only supports dall-e-2.

![warn] This module is untested! No OpenAI-compatible provider accessible to this project implements this endpoint, and no OpenAI API key was available for testing. If you encounter any issues, please report them on the repository.

Structs

ImageVariationRequest
Creates a variation of a given image.

Enums

VariationSize
The size of the generated variation images.