Module for deleting a fine-tuned model.
You must have the Owner role in your organization to delete a model.
![warn] This module is untested! OpenAI-compatible providers are not known to implement this endpoint. If you encounter any issues, please report them on the repository.