List the currently available models, and provide basic information about each one such as the owner and availability.
The list is tested against the DeepSeek GET /models endpoint. Other
OpenAI-compatible providers may return a different set of fields; unknown
fields are ignored during deserialization.