Module response

Module response 

Structs

Categories
A list of the categories, and whether they are flagged or not.
CategoryAppliedInputTypes
A list of the categories along with the input type(s) that the score applies to, e.g. ["text"] or ["text", "image"].
CategoryScores
A list of the categories along with their scores as predicted by the model.
Moderation
A moderation object.
ModerationCreateResponse
Represents if a given text input is potentially harmful.