pub struct Categories {Show 13 fields
pub harassment: Option<bool>,
pub harassment_threatening: Option<bool>,
pub hate: Option<bool>,
pub hate_threatening: Option<bool>,
pub illicit: Option<bool>,
pub illicit_violent: Option<bool>,
pub self_harm: Option<bool>,
pub self_harm_instructions: Option<bool>,
pub self_harm_intent: Option<bool>,
pub sexual: Option<bool>,
pub sexual_minors: Option<bool>,
pub violence: Option<bool>,
pub violence_graphic: Option<bool>,
}Expand description
A list of the categories, and whether they are flagged or not.
Fields are optional so that responses of different moderation model generations (which add or remove categories over time) can be deserialized.
Fields
harassment: Option<bool>harassment_threatening: Option<bool>hate: Option<bool>hate_threatening: Option<bool>illicit: Option<bool>illicit_violent: Option<bool>self_harm: Option<bool>self_harm_instructions: Option<bool>self_harm_intent: Option<bool>sexual: Option<bool>sexual_minors: Option<bool>violence: Option<bool>violence_graphic: Option<bool>Trait Implementations
Sourceimpl Clone for Categories
impl Clone for Categories
Sourcefn clone(&self) -> Categories
fn clone(&self) -> Categories
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for Categories
impl Debug for Categories
Sourceimpl Default for Categories
impl Default for Categories
Sourcefn default() -> Categories
fn default() -> Categories
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for Categories
impl<'de> Deserialize<'de> for Categories
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more