pub struct Moderation {
pub categories: Categories,
pub category_applied_input_types: Option<CategoryAppliedInputTypes>,
pub category_scores: CategoryScores,
pub flagged: bool,
}Expand description
A moderation object.
Fields
categories: CategoriesA list of the categories, and whether they are flagged or not.
category_applied_input_types: Option<CategoryAppliedInputTypes>A list of the categories along with the input type(s) that the score applies to.
category_scores: CategoryScoresA list of the categories along with their scores as predicted by the model.
flagged: boolWhether any of the categories are flagged.