ReasoningConfig

Struct ReasoningConfig 

pub struct ReasoningConfig {
    pub effort: Option<ReasoningEffort>,
    pub summary: Option<SummaryEffort>,
}
Configuration options for reasoning models.

Fields

effort: Option<ReasoningEffort>

Constrains the effort on reasoning. Reducing the effort can result in faster responses and fewer reasoning tokens. Providers accept subsets of the values and map unsupported values to their nearest effort level; DeepSeek maps none to thinking mode off.

summary: Option<SummaryEffort>

The verbosity of reasoning summaries generated by the model.