pub struct ListInputItemsRequest<'a> {
pub response_id: &'a str,
pub after: Option<&'a str>,
pub before: Option<&'a str>,
pub limit: Option<u32>,
pub order: Option<InputItemsOrder>,
pub extra_query: Option<HashMap<String, String>>,
}Expand description
Lists the input items of a previously created response by its ID.
Fields
response_id: &'a strThe ID of the response whose input items to list, e.g. resp_....
after: Option<&'a str>An item ID to list items after, used in pagination.
before: Option<&'a str>An item ID to list items before, used in pagination.
limit: Option<u32>A limit on the number of items to be returned (1-100, default 20).
order: Option<InputItemsOrder>The order to return the input items in (asc or desc).
extra_query: Option<HashMap<String, String>>Additional query parameters appended verbatim to the URL.