pub struct ResponseFunctionCall {
pub id: Option<String>,
pub call_id: Option<String>,
pub name: Option<String>,
pub arguments: Option<String>,
pub status: Option<ItemStatus>,
}Expand description
A call to a user-defined function.
Fields
id: Option<String>The unique ID of the function call.
call_id: Option<String>The ID used to pair this call with its function_call_output when
passing the result back in a follow-up request.
name: Option<String>The name of the function to call.
arguments: Option<String>The arguments to call the function with, as a JSON string.
status: Option<ItemStatus>The status of the function call item.