Module parts

Module parts 

Add an upload part via POST /uploads/{upload_id}/parts.

![warn] This module is untested! If you encounter any issues, please report them on the repository.

Each part can be up to 64 MB except the last, which may be smaller. Parts must be added in order and the combined size must match the declared upload size.

Structs

AddUploadPartRequest
Adds a chunk of bytes to an upload session.