Module files

Module files 

Manage the files of a vector store via /vector_stores/{vector_store_id}/files.

![warn] This module is untested! If you encounter any issues, please report them on the repository.

Submodules: retrieve, delete, list and content; the create endpoint lives directly in this module.

Modules

content
Retrieve the parsed contents of a vector store file via GET /vector_stores/{vector_store_id}/files/{file_id}/content.
delete
Delete a vector store file via DELETE /vector_stores/{vector_store_id}/files/{file_id}.
list
List the files of a vector store via GET /vector_stores/{vector_store_id}/files.
retrieve
Retrieve a vector store file via GET /vector_stores/{vector_store_id}/files/{file_id}.

Structs

CreateVectorStoreFileRequest
Adds a file to a vector store via POST /vector_stores/{vector_store_id}/files.