pub struct VectorStore {
pub id: String,
pub object: Option<String>,
pub created_at: Option<u64>,
pub last_active_at: Option<u64>,
pub name: Option<String>,
pub usage_bytes: Option<u64>,
pub expires_after: Option<Value>,
pub expires_at: Option<u64>,
pub file_counts: Option<VectorStoreFileCounts>,
pub metadata: Option<HashMap<String, String>>,
pub status: Option<String>,
}Expand description
A vector store.
Fields
id: StringThe vector store ID, e.g. vs_....
object: Option<String>The object type, always vector_store.
created_at: Option<u64>Unix timestamp (seconds) of when the store was created.
last_active_at: Option<u64>Unix timestamp (seconds) of when the store was last active.
name: Option<String>The name of the store.
usage_bytes: Option<u64>The number of bytes of storage used by the store.
expires_after: Option<Value>The expiration policy of the store, as raw JSON
({"anchor": "last_active_at", "days": N}).
expires_at: Option<u64>Unix timestamp (seconds) of when the store expires.
file_counts: Option<VectorStoreFileCounts>The file counts of the store.
metadata: Option<HashMap<String, String>>Arbitrary key-value metadata attached to the store.
status: Option<String>The status of the store (completed, expired, in_progress).