Module speech

Module speech 

Generates audio from the input text.

Endpoint: POST /audio/speech (JSON request / binary response). The response body is the raw audio bytes in the requested format.

Streaming audio (stream_format) is not supported yet.

![warn] This module is untested! No OpenAI-compatible provider accessible to this project implements this endpoint, and no OpenAI API key was available for testing. If you encounter any issues, please report them on the repository.

Structs

SpeechRequest
Generates audio from the input text.

Enums

SpeechFormat
The format of the generated audio.
SpeechVoice
The voice to use when generating audio.