The Batches API: run async batch processing jobs over collections of
requests via /batches.
![warn] This module is untested! If you encounter any issues, please report them on the repository.
A batch job reads a JSONL file of requests (uploaded through the
files API), processes all of them within the
completion window, and writes the results to an output file. See
the OpenAI Batch API guide.
Modules
- cancel
- Cancel a batch job via
POST /batches/{batch_id}/cancel. - create
- Create a batch job via
POST /batches. - list
- List batch jobs via
GET /batches. - retrieve
- Retrieve a batch job via
GET /batches/{batch_id}.
Structs
- Batch
- A batch processing job.
- Batch
Error - An error entry attached to a batch job.
- Batch
Errors - The error list of a batch job.
- Batch
Request Counts - The per-request result counts of a batch job.
Enums
- Batch
Status - The lifecycle status of a batch job.