Module chat

Module chat 

Chat Completions API Module

This module provides components shared by many submodules.

Modules

create
Create a chat completion request.
delete
Module for deleting a stored chat completion.
retrieve
Module for retrieving chat completions from OpenAI API.
update
Module for updating stored chat completions.

Structs

Annotation
An annotation for a chat completion message.
ChatCompletion
ChatCompletionAudio
If the audio output modality is requested, this object contains data about the audio response from the model. Learn more from OpenAI.
ChatCompletionMessage
ChatModeration
Moderation results for the request input and generated output.
Choice
ChoiceLogprobs
CompletionTokensDetails
CompletionUsage
MessageToolCallCustom
MessageToolCallFunction
ModerationSideResult
A moderation result produced for the response input or generated output.
PromptTokensDetails
TokenLogProb
TopLogprob
UrlCitation
A URL citation when the model uses a web search tool.

Enums

AnnotationType
ChatCompletionMessageToolCall
ChatCompletionObject
The object type, which is always chat.completion.
FinishReason
ModerationResultType
The object type of a moderation result. Always moderation_result.
ModerationSide
The moderation outcome for one side (input or output) of the completion: either successful results or an error produced while attempting moderation.
ResponseRole
ServiceTier
The service tier used for processing the request.