Streaming chat completion response.
Re-exports
pub use crate::chat::FinishReason;pub use crate::chat::Role as CompletionRole;pub use crate::chat::CompletionTokensDetails;pub use crate::chat::CompletionUsage;pub use crate::chat::PromptTokensDetails;
Structs
- Chat
Completion Chunk - Choice
Delta - Choice
Delta Function Call - Choice
Delta Tool Call - Choice
Delta Tool Call Function - Choice
Logprobs - Log probability information for a choice.
- Completion
Chunk Choice - Logprobe
Content - A list of message content tokens with log probability information.
- TopLogprob
- List of the most likely tokens and their log probability, at this token position. In rare cases, there may be fewer than the number of requested top_logprobs returned.
Enums
- Chat
Completion Chunk Object - The object type, which is always
chat.completion.chunk. - Choice
Delta Tool Call Type - The type of a streamed tool call.