pub struct ChatCompletion {
pub id: String,
pub choices: Vec<Choice>,
pub created: u64,
pub model: String,
pub service_tier: Option<ServiceTier>,
pub system_fingerprint: Option<String>,
pub object: Option<ChatCompletionObject>,
pub usage: Option<CompletionUsage>,
pub moderation: Option<ChatModeration>,
}Fields
id: StringA unique identifier for the chat completion.
choices: Vec<Choice>A list of chat completion choices. Can be more than one
if n is greater than 1.
created: u64The Unix timestamp (in seconds) of when the chat completion was created.
model: StringThe model used for the chat completion.
service_tier: Option<ServiceTier>Specifies the processing type used for serving the request.
- If set to ‘auto’, then the request will be processed with the service tier configured in the Project settings. Unless otherwise configured, the Project will use ‘default’.
- If set to ‘default’, then the request will be processed with the standard pricing and performance for the selected model.
- If set to ‘flex’ or ‘priority’, then the request will be processed with the corresponding service tier.
- When not set, the default behavior is ‘auto’.
When the service_tier parameter is set, the response body will include the
service_tier value based on the processing mode actually used to serve the
request. This response value may be different from the value set in the
parameter.
system_fingerprint: Option<String>The system fingerprint used for the chat completion.
Can be used in conjunction with the seed request parameter to understand when
backend changes have been made that might impact determinism.
object: Option<ChatCompletionObject>The object type, which is always chat.completion.
Some only when the backend sends a recognized value; some
non-OpenAI gateways omit or repurpose the field.
usage: Option<CompletionUsage>Usage statistics for the completion request.
moderation: Option<ChatModeration>Moderation results for the request input and generated output.
Present when moderated completions are requested via the moderation
request parameter.