pub struct ChatCompletionMessage {
pub role: Role,
pub audio: Option<ChatCompletionAudio>,
pub content: Option<String>,
pub reasoning_content: Option<String>,
pub tool_calls: Option<Vec<ChatCompletionMessageToolCall>>,
pub refusal: Option<String>,
pub annotations: Option<Vec<Annotation>>,
}Fields
role: RoleThe role of the author of this message. This shall always
be Role::Assistant
audio: Option<ChatCompletionAudio>If the audio output modality is requested, this object contains data about the audio response from the model. Learn more from OpenAI.
content: Option<String>The contents of the message.
reasoning_content: Option<String>For thinking models: the reasoning contents of the assistant message, before the final answer.
tool_calls: Option<Vec<ChatCompletionMessageToolCall>>The tool calls generated by the model, such as function calls. Tool calls deserialization is not supported yet.
refusal: Option<String>The refusal message generated by the model.
annotations: Option<Vec<Annotation>>Annotations for the message, when applicable, such as URL citations when the model uses a web search tool.