Retrieve the raw content of a container file via
GET /containers/{container_id}/files/{file_id}/content.
![warn] This module is untested! If you encounter any issues, please report them on the repository.
The response body is the raw file bytes, so the request is issued
through GetBinary.
Structs
- Container
File Content Request - Retrieves the raw bytes of a container file.