Structs
- Create
Embedding Response - The response of an embedding request.
- Embedding
- Represents an embedding vector returned by the embedding endpoint.
- Usage
- The usage information for an embedding request.
Enums
- Embedding
Vector - The embedding vector, either as a list of floats or (with
encoding_format: "base64") as a base64 encoded string.