pub struct ImageEditRequest {Show 14 fields
pub image: Vec<PathBuf>,
pub prompt: String,
pub model: Option<String>,
pub background: Option<Background>,
pub input_fidelity: Option<InputFidelity>,
pub mask: Option<PathBuf>,
pub n: Option<u32>,
pub output_compression: Option<u32>,
pub output_format: Option<OutputFormat>,
pub quality: Option<Quality>,
pub response_format: Option<ImageResponseFormat>,
pub size: Option<String>,
pub user: Option<String>,
pub extra_body_map: Option<Map<String, Value>>,
}Expand description
Creates an edited or extended image given an original image and a prompt.
Fields
image: Vec<PathBuf>The image(s) to edit, as file paths.
For the GPT image models, each image should be a png, webp, or
jpg file less than 50MB. You can provide up to 16 images. For
dall-e-2, you can only provide one image, and it should be a square
png file less than 4MB.
Serialized as repeated image[] multipart parts when more than one
image is provided, matching the official SDK.
prompt: StringA text description of the desired image(s).
The maximum length is 1000 characters for dall-e-2, and 32000
characters for the GPT image models.
model: Option<String>The model to use for image generation. One of dall-e-2 or a GPT
image model (gpt-image-1, gpt-image-1-mini, gpt-image-1.5,
gpt-image-2, gpt-image-2-2026-04-21, or chatgpt-image-latest).
Defaults to gpt-image-1.5.
background: Option<Background>Allows to set transparency for the background of the generated
image(s). Must be one of transparent, opaque, or auto (default
value).
input_fidelity: Option<InputFidelity>Control how much effort the model will exert to match the style and
features, especially facial features, of input images. This parameter
is only supported for gpt-image-1 and gpt-image-1.5 and later
models, unsupported for gpt-image-1-mini. Supports high and
low. Defaults to low.
mask: Option<PathBuf>An additional image (as a file path) whose fully transparent areas
(e.g. where alpha is zero) indicate where image should be edited.
If there are multiple images provided, the mask will be applied on
the first image. Must be a valid PNG file, less than 4MB, and have
the same dimensions as image.
n: Option<u32>The number of images to generate. Must be between 1 and 10.
output_compression: Option<u32>The compression level (0-100%) for the generated images.
This parameter is only supported for the GPT image models with the
webp or jpeg output formats, and defaults to 100.
output_format: Option<OutputFormat>The format in which the generated images are returned.
This parameter is only supported for the GPT image models. Must be
one of png, jpeg, or webp. The default value is png.
quality: Option<Quality>The quality of the image that will be generated for GPT image models.
Defaults to auto.
response_format: Option<ImageResponseFormat>The format in which the generated images are returned. Must be one of
url or b64_json. This parameter is only supported for dall-e-2
(default is url for dall-e-2), as GPT image models always return
base64-encoded images.
size: Option<String>The size of the generated images. See the official documentation for the per-model size options.
user: Option<String>A unique identifier representing your end-user, which can help OpenAI to monitor and detect abuse.
extra_body_map: Option<Map<String, Value>>Additional JSON properties, sent as extra multipart text fields (strings verbatim, other JSON values serialized).