ImageVariationRequest

Struct ImageVariationRequest 

pub struct ImageVariationRequest {
    pub image: PathBuf,
    pub model: Option<String>,
    pub n: Option<u32>,
    pub response_format: Option<ImageResponseFormat>,
    pub size: Option<VariationSize>,
    pub user: Option<String>,
}
Creates a variation of a given image.

Fields

image: PathBuf

The image to use as the basis for the variation(s), as a file path.

Must be a valid PNG file, less than 4MB, and square.

model: Option<String>

The model to use for image generation. Only dall-e-2 is supported at this time.

n: Option<u32>

The number of images to generate. Must be between 1 and 10.

response_format: Option<ImageResponseFormat>

The format in which the generated images are returned. Must be one of url or b64_json. URLs are only valid for 60 minutes after the image has been generated.

size: Option<VariationSize>

The size of the generated images. Must be one of 256x256, 512x512, or 1024x1024.

user: Option<String>

A unique identifier representing your end-user, which can help OpenAI to monitor and detect abuse.