List and describe the various models available in the API.
Submodules: list, retrieve, and delete for specific model operations.
Modules
- delete
- Module for deleting a fine-tuned model.
- list
- List the currently available models, and provide basic information about each one such as the owner and availability.
- retrieve
- Module for retrieving a model instance, providing basic information about the model such as the owner and permissioning.
Structs
- Model
- Describes an OpenAI model offering that can be used with the API.