Module for retrieving a model instance, providing basic information about the model such as the owner and permissioning.
![warn] This module is untested! OpenAI-compatible providers are not known to implement this endpoint. If you encounter any issues, please report them on the repository.