Given text and/or image inputs, classifies if those inputs are potentially harmful.
![warn] This module is untested! OpenAI-compatible providers (DeepSeek, Qwen) are not known to implement this endpoint, and no OpenAI API key was available for testing. If you encounter any issues, please report them on the repository.